Bibliography — dtw_loss_functions documentation

# Bibliography

If you use this package please cite [ZBC25].

## First Section

If you use SoftDTW please also cite the following works, based on the implementation you decide to use.

- `mag` cite [Mag20] [MTL21]

    - GitHub Repository : https://github.com/Maghoumi/pytorch-softdtw-cuda

- `pysdtw` To the best of our knowledge no paper or any other work was mentioned in the GitHub page and PyPi page of this SDTW implementation.

    - GitHub repo : https://github.com/toinsson/pysdtw

    - PyPi Page : https://pypi.org/project/pysdtw/

- `ron` cite [WF26] [SWBL+25]

    - GitHub Repository : https://github.com/BGU-CS-VIL/sdtw-cuda-torch

## References list

[LLSH23]

Fabian Latorre, Chenghao Liu, Doyen Sahoo, and Steven C.H. Hoi. Otw: optimal transport warping for time series. In ICASSP 2023 - 2023 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP), volume, 1–5. 2023. doi:10.1109/ICASSP49357.2023.10095915.

[Mag20]

Mehran Maghoumi. Deep Recurrent Networks for Gesture Recognition and Synthesis. PhD thesis, University of Central Florida Orlando, Florida, 2020.

[MTL21]

Mehran Maghoumi, Eugene Matthew Taranta, and Joseph LaViola. Deepnag: deep non-adversarial gesture generation. In 26th International Conference on Intelligent User Interfaces, 213–223. 2021.

[SWBL+25]

Ron Shapira Weber, Shahar Benishay, Andrey Lavrinenko, Shahaf E. Finder, and Oren Freifeld. TimePoint: accelerated time series alignment via self-supervised keypoint and descriptor learning. In Aarti Singh, Maryam Fazel, Daniel Hsu, Simon Lacoste-Julien, Felix Berkenkamp, Tegan Maharaj, Kiri Wagstaff, and Jerry Zhu, editors, Proceedings of the 42nd International Conference on Machine Learning, volume 267 of Proceedings of Machine Learning Research, 54275–54299. PMLR, 13–19 Jul 2025. URL: https://proceedings.mlr.press/v267/shapira-weber25a.html.

[WF26]

Ron Shapira Weber and Oren Freifeld. Softdtw-cuda-torch: memory-efficient gpu-accelerated soft dynamic time warping for pytorch. 2026. URL: https://arxiv.org/abs/2602.17206, arXiv:2602.17206.

[ZBC25]

Alberto Zancanaro, Leonardo Badia, and Giulia Cisotto. Blockdtw: efficient and scalable similarity search algorithm for healthcare-focused time-series. In 2025 IEEE Conference on Standards for Communications and Networking (CSCN), volume, 1–6. 2025. doi:10.1109/CSCN67557.2025.11230700.